pyoda\_time.time\_zones package
===============================

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   pyoda_time.time_zones.cldr
   pyoda_time.time_zones.io

Module contents
---------------

.. automodule:: pyoda_time.time_zones
   :members:
   :undoc-members:
   :show-inheritance:
